@@ -2,11 +2,16 @@ package Catalyst::Plugin::Session::PerUser::AutoLogout;
 use Moose;
 extends 'Catalyst::Plugin::Session::PerUser';
 
+our $VERSION = '0.002';
+
 after set_authenticated => sub {
     my $c = shift;
+
     if (my $existing_session = $c->user_session->{session_id}) {
-        $c->delete_session($existing_session);
+        $c->delete_session_data("${_}:$existing_session") for qw/session flash expires/;
+        $c->user_session->{logged_out} = $existing_session;
     }
+
     $c->user_session->{session_id} = $c->sessionid;
 };
 
